@@ -33,7 +33,8 @@ class Algorithm(BaseResource):
         return self._data.get("environments")
 
     def get_environment(self, name):
-        environment_id = "{}:{}:{}".format(self.user["teamId"], self.id, name)
+        team_id = self.team_id if self.team_id else self.user["teamId"]
+        environment_id = "{}:{}:{}".format(team_id, self.id, name)
         return AlgorithmEnvironment(environment_id, session=self.session)
 
     def create_environment(self, name, *, invoke_function=None):
